Mandel plugin Barebone
=====================
Installation
-------------
Add `ocyan.plugin.barebone` to your projects dependencies.


About & Usage of Barebone
-------------------------
Mandel with only the bare minimum for making content websites.


ocyan.i18n
-------------
If you have added the `ocyan.i18n` package to your dependencies, this plugin will add the required settings to your settings. See the ocyan.i18n readme for more information on that plugin.
